#ifndef DOVEADM_DSYNC_H
#define DOVEADM_DSYNC_H

extern struct doveadm_cmd_ver2 doveadm_cmd_dsync_mirror;
extern struct doveadm_cmd_ver2 doveadm_cmd_dsync_backup;
extern struct doveadm_cmd_ver2 doveadm_cmd_dsync_server;

#endif
